%%%%%%%%%%%%%%%%%%%%%% Example Code: Graphics %%%%%%%%%%%%%%%%%%%%%%
% Example code for Bayesian Function-on-Function Regression for    %
%  Multi-Level Functional Data                                     %
% By Meyer, MJ, Coull, BA, Versace, F, Cinciripini, P, and Morris, %
%  JS.                                                             %
%                                                                  %
% After generating estimates using sample_scrtip.m and the WFMM    %
% exectuable, this script generates graphics similar to those in   %
% the manuscript and web-based supplemenatary material.            %
%                                                                  %
% Created:      9/19/2014                                          %
% Modified:     --/--/----                                         %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

addpath('/OUTPUT')

%% load postProcess.mat %%
load('postProcess.mat')

%% graphical parameters %%
[v, t]  = meshgrid(0:1:(225-1));
label   = ['v'; 't'];
zmin    = -0.03;
zmax    = 0.11;
Xaxis   = [0 (225-1)];
Yaxis   = [0 (225-1)];

%% heatmap of estimated surface %%
figure
colormap(hot)
imagesc(postout.bhat',[zmin,zmax])
colorbar
set(gca,'Ydir','reverse','Xdir','reverse')
set(gca,'FontSize',16)
set(gca,'YTick',[1,75:75:225],'YTickLabel',[225,150,75,0])
set(gca,'XTick',[1,75:75:225],'XTickLabel',[225,150,75,0])
xlabel('v','FontSize',14)
ylabel('t','FontSize',14)
title('Ridge Estimate','FontSize',14)

%% heatmpa of BFDR %%
figure
colormap(hot) %autumn
imagesc(postout.psi');
hcb = colorbar;
set(gca,'Ydir','reverse','Xdir','reverse')
set(gca,'FontSize',16)
set(gca,'YTick',[1,75:75:225],'YTickLabel',[225,150,75,0])
set(gca,'XTick',[1,75:75:225],'XTickLabel',[225,150,75,0])
set(hcb,'YTick',[0,0.2,0.4,0.6,0.8,1])
xlabel('v','FontSize',14)
ylabel('t','FontSize',14)
title('Ridge BFDR')

%% plot of MAPs %%
figure
colormap(flipud(hot))
imagesc(log(postout.SimBaS), [log(0.0009),log(0.5)+0.001])
hcb=colorbar;
set(gca,'Ydir','reverse','Xdir','reverse')
set(gca,'FontSize',16)
set(gca,'YTick',[1,75:75:225],'YTickLabel',[225,150,75,0])
set(gca,'XTick',[1,75:75:225],'XTickLabel',[225,150,75,0])
title('Ridge SimBaS')
set(hcb,'YTick',[log(0.001) log(0.01) log(0.05) log(0.1) log(0.25) log(0.5)])
set(hcb,'YTickLabel',roundn([0.001 0.01 0.05 0.1 0.25 0.5],-4))



